pub struct Github;Trait Implementations
Sourceimpl Platform for Github
impl Platform for Github
Sourcefn fetch_releases(
project: &str,
tag: Option<&str>,
) -> Result<Vec<Self::Release>, DownloadError>
fn fetch_releases( project: &str, tag: Option<&str>, ) -> Result<Vec<Self::Release>, DownloadError>
Fetches releases for the given GitHub repository, optionally filtered by a specific tag.
If tag is provided, fetches the release that matches that tag; otherwise fetches the repository’s releases (up to 100 per page).
Arguments
project— repository identifier in the form “owner/repo”.tag— optional release tag to filter the results.
Returns
Ok with a vector of releases on success, or Err(DownloadError) on failure.
Examples
use soar_dl::github::Github;
use soar_dl::traits::{Platform, Release};
let releases = Github::fetch_releases("rust-lang/rust", None).unwrap();
assert!(releases.iter().all(|r| r.tag().len() > 0));const API_PKGFORGE: &'static str = "https://api.gh.pkgforge.dev"
const API_UPSTREAM: &'static str = "https://api.github.com"
const TOKEN_ENV: [&str; 2]
type Release = GithubRelease