pub struct GithubRelease {
pub name: Option<String>,
pub tag_name: String,
pub prerelease: bool,
pub published_at: String,
pub body: Option<String>,
pub assets: Vec<GithubAsset>,
}Fields
name: Option<String>tag_name: Stringprerelease: boolpublished_at: Stringbody: Option<String>assets: Vec<GithubAsset>Trait Implementations
Sourceimpl Clone for GithubRelease
impl Clone for GithubRelease
Sourcefn clone(&self) -> GithubRelease
fn clone(&self) -> GithubRelease
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GithubRelease
impl Debug for GithubRelease
Sourceimpl<'de> Deserialize<'de> for GithubRelease
impl<'de> Deserialize<'de> for GithubRelease
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Release for GithubRelease
impl Release for GithubRelease
Sourcefn name(&self) -> &str
fn name(&self) -> &str
The release’s name, or an empty string if the release has no name.
Examples
use soar_dl::github::GithubRelease;
use soar_dl::traits::Release;
let r = GithubRelease {
name: Some("v1.0".into()),
tag_name: "v1.0".into(),
prerelease: false,
published_at: "".into(),
body: None,
assets: vec![],
};
assert_eq!(r.name(), "v1.0");
let unnamed = GithubRelease {
name: None,
tag_name: "v1.1".into(),
prerelease: false,
published_at: "".into(),
body: None,
assets: vec![],
};
assert_eq!(unnamed.name(), "");Sourcefn tag(&self) -> &str
fn tag(&self) -> &str
Get the release tag as a string slice.
Examples
use soar_dl::github::GithubRelease;
use soar_dl::traits::Release;
let release = GithubRelease {
name: None,
tag_name: "v1.0.0".into(),
prerelease: false,
published_at: "".into(),
body: None,
assets: vec![],
};
assert_eq!(release.tag(), "v1.0.0");Returns
&str containing the release tag.
Sourcefn is_prerelease(&self) -> bool
fn is_prerelease(&self) -> bool
Indicates whether the release is marked as a prerelease.
Returns
true if the release is marked as a prerelease, false otherwise.
Examples
use soar_dl::github::GithubRelease;
use soar_dl::traits::Release;
let r = GithubRelease {
name: None,
tag_name: "v1.0.0".to_string(),
prerelease: true,
published_at: "".to_string(),
body: None,
assets: vec![],
};
assert!(r.is_prerelease());Sourcefn published_at(&self) -> &str
fn published_at(&self) -> &str
Returns the release’s publication timestamp as an RFC 3339 formatted string.
Examples
use soar_dl::github::GithubRelease;
use soar_dl::traits::Release;
let r = GithubRelease {
name: None,
tag_name: "v1.0.0".into(),
prerelease: false,
published_at: "2021-01-01T00:00:00Z".into(),
body: None,
assets: vec![],
};
assert_eq!(r.published_at(), "2021-01-01T00:00:00Z");Sourcefn assets(&self) -> &[Self::Asset]
fn assets(&self) -> &[Self::Asset]
Get a slice of assets associated with the release.
The slice contains the release’s assets in declaration order.
Examples
use soar_dl::github::{GithubRelease, GithubAsset};
use soar_dl::traits::Release;
let asset = GithubAsset {
name: "example.zip".into(),
size: 1024,
browser_download_url: "https://example.com/example.zip".into(),
};
let release = GithubRelease {
name: Some("v1.0".into()),
tag_name: "v1.0".into(),
prerelease: false,
published_at: "2025-01-01T00:00:00Z".into(),
body: None,
assets: vec![asset],
};
assert_eq!(release.assets().len(), 1);type Asset = GithubAsset
fn body(&self) -> Option<&str>